@@ -47,18 +47,19 @@ filterwarnings("ignore", category=DeprecationWarning)
 
 class method:
 
-    def __init__(self, func):
+    def __init__(self, /, func):
         self.__func__ = func
 
-    def __setname__(self, instance, name):
-        self.__method__ = MethodType(self.__func__, instance)
-
-    def __get__(self, instance, type=None):
+    def __get__(self, instance, type=None, /):
         if instance is None:
             return self
-        return self.__method__
+        try:
+            return self.__method__
+        except AttributeError:
+            method = self.__method__ = MethodType(self.__func__, instance)
+            return method
 
-    def __set__(self, instance, value):
+    def __set__(self, instance, value, /):
         raise TypeError("can't set value")
 
 
